import * as pgwire from '@powersync/service-jpgwire';
export class PgManager {
    constructor(options, poolOptions) {
        this.options = options;
        this.poolOptions = poolOptions;
        this.connectionPromises = [];
        // The pool is lazy - no connections are opened until a query is performed.
        this.pool = pgwire.connectPgWirePool(this.options, poolOptions);
    }
    get connectionTag() {
        return this.options.tag;
    }
    /**
     * Create a new replication connection.
     */
    async replicationConnection() {
        const p = pgwire.connectPgWire(this.options, { type: 'replication' });
        this.connectionPromises.push(p);
        return await p;
    }
    /**
     * Create a new standard connection, used for initial snapshot.
     *
     * This connection must not be shared between multiple async contexts.
     */
    async snapshotConnection() {
        const p = pgwire.connectPgWire(this.options, { type: 'standard' });
        this.connectionPromises.push(p);
        return await p;
    }
    async end() {
        for (let result of await Promise.allSettled([
            this.pool.end(),
            ...this.connectionPromises.map(async (promise) => {
                const connection = await promise;
                return await connection.end();
            })
        ])) {
            // Throw the first error, if any
            if (result.status == 'rejected') {
                throw result.reason;
            }
        }
    }
    async destroy() {
        this.pool.destroy();
        for (let result of await Promise.allSettled([
            ...this.connectionPromises.map(async (promise) => {
                const connection = await promise;
                return connection.destroy();
            })
        ])) {
            // Throw the first error, if any
            if (result.status == 'rejected') {
                throw result.reason;
            }
        }
    }
}
//# sourceMappingURL=PgManager.js.map