import { SourceEntityDescriptor, storage } from '@powersync/service-core';
import * as pgwire from '@powersync/service-jpgwire';
import { DatabaseInputRow, SqliteRow, SqlSyncRules, TablePattern } from '@powersync/service-sync-rules';
import { PgManager } from './PgManager.js';
export declare const ZERO_LSN = "00000000/00000000";
export declare const PUBLICATION_NAME = "powersync";
export declare const POSTGRES_DEFAULT_SCHEMA = "public";
export interface WalStreamOptions {
    connections: PgManager;
    storage: storage.SyncRulesBucketStorage;
    abort_signal: AbortSignal;
}
interface InitResult {
    needsInitialSync: boolean;
}
export declare class MissingReplicationSlotError extends Error {
    constructor(message: string);
}
export declare class WalStream {
    sync_rules: SqlSyncRules;
    group_id: number;
    connection_id: number;
    private readonly storage;
    private readonly slot_name;
    private connections;
    private abort_signal;
    private relation_cache;
    private startedStreaming;
    constructor(options: WalStreamOptions);
    get stopped(): boolean;
    getQualifiedTableNames(batch: storage.BucketStorageBatch, db: pgwire.PgConnection, tablePattern: TablePattern): Promise<storage.SourceTable[]>;
    initSlot(): Promise<InitResult>;
    estimatedCount(db: pgwire.PgConnection, table: storage.SourceTable): Promise<string>;
    /**
     * Start initial replication.
     *
     * If (partial) replication was done before on this slot, this clears the state
     * and starts again from scratch.
     */
    startInitialReplication(replicationConnection: pgwire.PgConnection): Promise<void>;
    initialReplication(db: pgwire.PgConnection, lsn: string): Promise<void>;
    static getQueryData(results: Iterable<DatabaseInputRow>): Generator<SqliteRow>;
    private snapshotTable;
    handleRelation(batch: storage.BucketStorageBatch, descriptor: SourceEntityDescriptor, snapshot: boolean): Promise<storage.SourceTable>;
    private getTable;
    writeChange(batch: storage.BucketStorageBatch, msg: pgwire.PgoutputMessage): Promise<storage.FlushedResult | null>;
    replicate(): Promise<void>;
    initReplication(replicationConnection: pgwire.PgConnection): Promise<void>;
    streamChanges(replicationConnection: pgwire.PgConnection): Promise<void>;
    ack(lsn: string, replicationStream: pgwire.ReplicationStream): Promise<void>;
}
export {};
